@@ -20,107 +20,52 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-cloudfront-apigateway`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.cloudfrontapigateway`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS CloudFront fronting an Amazon API Gateway REST API.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
-Typescript
-
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
+```javascript
+import * as api from '@aws-cdk/aws-apigateway';
+import * as lambda from "@aws-cdk/aws-lambda";
 import { CloudFrontToApiGateway } from '@aws-solutions-constructs/aws-cloudfront-apigateway';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-import * as api from 'aws-cdk-lib/aws-apigateway';
 
 const lambdaProps: lambda.FunctionProps = {
-  code: lambda.Code.fromAsset(`lambda`),
-  runtime: lambda.Runtime.NODEJS_14_X,
-  handler: 'index.handler'
+    code: lambda.Code.fromAsset(`${__dirname}/lambda`),
+    runtime: lambda.Runtime.NODEJS_14_X,
+    handler: 'index.handler'
 };
 
 const lambdafunction = new lambda.Function(this, 'LambdaFunction', lambdaProps);
 
 const apiGatewayProps: api.LambdaRestApiProps = {
-  handler: lambdafunction,
-  endpointConfiguration: {
-    types: [api.EndpointType.REGIONAL]
-  },
-  defaultMethodOptions: {
-    authorizationType: api.AuthorizationType.NONE
-  }
+        handler: lambdafunction,
+        endpointConfiguration: {
+            types: [api.EndpointType.REGIONAL]
+        },
+        defaultMethodOptions: {
+            authorizationType: api.AuthorizationType.NONE
+        }
 };
 
 const apiGateway = new api.LambdaRestApi(this, 'LambdaRestApi', apiGatewayProps);
 
 new CloudFrontToApiGateway(this, 'test-cloudfront-apigateway', {
-  existingApiGatewayObj: apiGateway
+    existingApiGatewayObj: apiGateway
 });
+
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_cloudfront_apigateway import CloudFrontToApiGateway
-from aws_cdk import (
-    aws_lambda as _lambda,
-    aws_apigateway as api,
-    Stack
-)
-from constructs import Construct
-
-lambda_function = _lambda.Function(self, 'LambdaFunction',
-                                    code=_lambda.Code.from_asset(
-                                        'lambda'),
-                                    runtime=_lambda.Runtime.PYTHON_3_9,
-                                    handler='index.handler')
-
-api_gateway = api.LambdaRestApi(self, 'LambdaRestApi',
-                                handler=lambda_function,
-                                endpoint_configuration=api.EndpointConfiguration(
-                                    types=[api.EndpointType.REGIONAL]
-                                ),
-                                default_method_options=api.MethodOptions(
-                                    authorization_type=api.AuthorizationType.NONE
-                                ))
-
-CloudFrontToApiGateway(self, 'test-cloudfront-apigateway',
-                        existing_api_gateway_obj=api_gateway
-                        )
+```text
+new CloudFrontToApiGateway(scope: Construct, id: string, props: CloudFrontToApiGatewayProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-import java.util.List;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awscdk.services.apigateway.*;
-import software.amazon.awsconstructs.services.cloudfrontapigateway.*;
-
-final Function lambdaFunction = Function.Builder.create(this, "IndexHandler")
-        .runtime(Runtime.NODEJS_14_X)
-        .code(Code.fromAsset("lambda"))
-        .handler("index.handler")
-        .build();
-
-final LambdaRestApi apiGateway = LambdaRestApi.Builder.create(this, "myapi")
-        .handler(lambdaFunction)
-        .endpointConfiguration(new EndpointConfiguration.Builder()
-                .types(List.of(EndpointType.REGIONAL))
-                .build())
-        .build();
-
-new CloudFrontToApiGateway(this, "test-cloudfront-apigateway", new CloudFrontToApiGatewayProps.Builder()
-        .existingApiGatewayObj(apiGateway)
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`CloudFrontToApiGatewayProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -161,7 +106,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -173,29 +118,27 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
 import aws_cdk.aws_cloudfront
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class CloudFrontToApiGateway(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-cloudfront-apigateway.CloudFrontToApiGateway",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        cloud_front_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -210,20 +153,6 @@ class CloudFrontToApiGateway(
         :since: 0.8.0
         :summary: Constructs a new instance of the CloudFrontToApiGateway class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
-                cloud_front_distribution_props: typing.Any = None,
-                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                insert_http_security_headers: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToApiGatewayProps(
             existing_api_gateway_obj=existing_api_gateway_obj,
             cloud_front_distribution_props=cloud_front_distribution_props,
@@ -233,22 +162,22 @@ class CloudFrontToApiGateway(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudFrontWebDistribution")
     def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
         return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudFrontFunction")
     def cloud_front_function(self) -> typing.Optional[aws_cdk.aws_cloudfront.Function]:
         return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.Function], jsii.get(self, "cloudFrontFunction"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
     def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
@@ -270,7 +199,7 @@ class CloudFrontToApiGatewayProps:
         *,
         existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        cloud_front_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -283,20 +212,6 @@ class CloudFrontToApiGatewayProps:
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
             cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
-        if __debug__:
-            def stub(
-                *,
-                existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
-                cloud_front_distribution_props: typing.Any = None,
-                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                insert_http_security_headers: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument existing_api_gateway_obj", value=existing_api_gateway_obj, expected_type=type_hints["existing_api_gateway_obj"])
-            check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
-            check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
-            check_type(argname="argument insert_http_security_headers", value=insert_http_security_headers, expected_type=type_hints["insert_http_security_headers"])
         self._values: typing.Dict[str, typing.Any] = {
             "existing_api_gateway_obj": existing_api_gateway_obj,
         }
